# Awesome Explorables ![Awesome](https://cdn.rawgit.com/sindresorhus/awesome/d7305f38d29fed78fa85652e3a63e154dd8e8829/media/badge.svg)

A curated list of awesome [explorable explanations](http://worrydream.com/#!/ExplorableExplanations). 

Inspired by Bret Vector and [awesome](github.com/sindresorhus/awesome).

## Contributing

You are welcome to create a PR to contribute. 

Please take a a look at [contribution guidelines](https://github.com/sp4ke/awesome-explorables/blob/master/CONTRIBUTING.md). 

#### *If you see a link or a project that is broken or no longer working, please submit a pull request to improve this file. Thank you !*

Join us on slack at [**#awesome-explorables**](https://awesome-explorables.com/) or reddit at [/r/explorables](www.reddit.com/r/explorables/)

## Contents

- [Math](#math) 
	- [Statistics And Probability](#statistics-and-probability)
	- [Linear Algebra](#linear-algebra)
	- [Trigonometry](#trigonometry)
	- [Logic](#logic)
- [Algorithms](#algorithms)
	- [Machine Learning And Neural Networks](#machine-learning-and-neural-networks)
	- [Game Programming](#game-programming)
	- [Data Structures](#data-structures)
- [Science](#science)
- [Physics](#physics)
- [Psychology - Human Machine Interface](#psychology-human-machine-interface)
- [Other](#other)
- [About Explorable Explanations](#about-explorable-explanations)
- [Tools for Explorable Explanations](#tools-for-explorable-explanations)
-  [Books](#books)

## Math

*[&#8593; top](#contents)*
* [Explained Visually](http://setosa.io/ev/)
  * [Image Kernels](http://setosa.io/ev/image-kernels/)
  * [Pi (π)](http://setosa.io/ev/pi/)
  * [Exponentiation](http://setosa.io/ev/exponentiation/)
* [Better Explained](https://betterexplained.com) - Math without endless memorization
* [Euclid: The Game](http://euclidthegame.com/)
* [The Hitchhiker's Guide To The Mandelbrot set](https://morr.cc/mandelbrot/) 
* [vf.rohanp.xyz](http://vf.rohanp.xyz/) - an interactive demonstration of vector field flow

### Statistics And Probability
*[&#8593; top](#contents)*
* [Seeing Theory](http://students.brown.edu/seeing-theory/) - a visual introduction to probability and statistics
* [Principal Component Analysis](http://setosa.io/ev/principal-component-analysis/)
* [Conditional Probability](http://setosa.io/ev/conditional-probability/)
* [Ordinary Least Squares Regression](http://setosa.io/ev/ordinary-least-squares-regression/)
* [Markov Chains](http://setosa.io/ev/markov-chains/)
* [Science Isn't Broken](https://fivethirtyeight.com/features/science-isnt-broken/#part1) - On scientific method (p-values)
* [Humans Suck At Entropy](http://www.loper-os.org/bad-at-entropy/manmach.html) 
* [Simpson's Paradox](http://vudlab.com/simpsons/)

### Linear Algebra
*[&#8593; top](#contents)*
* [Eigenvectors and Eigenvalues](http://setosa.io/ev/eigenvectors-and-eigenvalues/)
* [Interactive 2d Matrix](http://ncase.me/matrix/)
* [Immersive Math](http://immersivemath.com/ila/)  – a linear algebra book with  ully interactive figures

### Trigonometry
*[&#8593; top](#contents)*
* [Circles Sines and Signals](http://jackschaedler.github.io/circles-sines-signals/)  – a visual explanation of the fourier transform by jack schaedler
* [Sine and Cosine](http://setosa.io/ev/sine-and-cosine/)

### Logic
*[&#8593; top](#contents)*
* [The Incredible Proof Machine](http://incredible.pm/) – a visual approach to propositional logic




## Algorithms

*[&#8593; top](#contents)*
* [Visualizing Algorithms](https://bost.ocks.org/mike/algorithms/) - visualizing algorithms, by mike bostock
* [visualgo.net](https://visualgo.net) - interactive computer science algorithms and data structures
* [Quicksort](https://illustrated-algorithms.now.sh/quicksort) - the quicksort algorithm, illustrated with playing cards
* [Second-Order Controls](https://medium.com/@max_goldstein/second-order-controls-5cee5ddc9d2d)
* [How to Use t-SNE Effectively](http://distill.pub/2016/misread-tsne/) - Visualizing high-dimensional data
* [Promisees](http://bevacqua.github.io/promisees/) - Promise visualization playground for the adventurous

### Machine Learning and Neural Networks
*[&#8593; top](#contents)*
* [r2d3.us](http://www.r2d3.us/visual-intro-to-machine-learning-part-1/) - a visual introduction to machine learning
* [Neural Networks And Deep Learning](http://neuralnetworksanddeeplearning.com/) - Free online interactive book about Neural Networks and Deep Learning.
* [playground.tensorflow.org](http://playground.tensorflow.org/) - a neural network playground

### Game Programming
*[&#8593; top](#contents)*
* [redblobgames.com](http://www.redblobgames.com/)
	* [Introduction To A* ](http://www.redblobgames.com/pathfinding/a-star/introduction.html) – how pathfinding algorithms work, by amit patel
	* [Hexagonal Grids](http://www.redblobgames.com/grids/hexagons/) - an interactive guide on implementing hexagonal grids
	* [Intro To Graph Theory](http://www.redblobgames.com/pathfinding/grids/graphs.html)
* [Generating Fantasy Maps](http://mewo2.com/notes/terrain/) - generating fantasy maps – the math behind 
* [gamejolt.com](http://gamejolt.com/games/the-stranger-loop/10679) - topology, via asteroids, narrated


### Data Structures
*[&#8593; top](#contents)*
* [Quadtree](http://jimkang.com/quadtreevis/) - an interactive explanation of quadtrees, by jim kang
* [Bitcoin Blockchain](https://anders.com/blockchain/) - "blockchain demo" explains the basics behind decentralized cryptocurrencies like bitcoin



## Science
*[&#8593; top](#contents)*
* [ncase.me](http://ncase.me/simulating/) - simulating the world (in emoji😘)
* [ncase.me](http://ncase.me/neurons/) - neurotic neurons, an interactive animation on how exposure therapy works
*[Grail Handwriting Recognizer](https://jackschaedler.github.io/handwriting-recognition/) - jack schaedler's active essay on how the grail handwriting recognizer works
* [Exploring Emergence](http://www.playfulinvention.com/emergence/index.html) -  an introduction to cellular automata (from 1996! requires flash.)
* [internet-atlas.net](http://internet-atlas.net/) - critical atlas of internet
* [Visualizing Projections](http://shaunlebron.github.io/visualizing-projections/) - visualizing multiple camera projection techniques

## Physics
*[&#8593; top](#contents)*
* [arogozhnikov.github.io](https://arogozhnikov.github.io/2016/12/19/markov_chain_monte_carlo.html) - hamiltonian monte carlo explained
* [Nukemap](http://nuclearsecrecy.com/nukemap/) - nuclear explosion simulation tool by alex wellerstein
* [Angry Physics](http://ncase.me/birds/) 


## Psychology Human Machine Interface
*[&#8593; top](#contents)*
* [To Build A Better Ballot](http://ncase.me/ballot/) – an interactive guide to alternative voting systems
* [recursivedrawing.com](http://recursivedrawing.com/) - by toby schachman lets you create complex patterns from simple building blocks
* [Parable Of the Polygons](http://ncase.me/polygons/)  – a simulation about segregation and diversity
* [Learning By Doing](http://blog.ncase.me/i-do-and-i-understand/) 

## Other
*[&#8593; top](#contents)*
* [Ishkur's Guide To Electronic Music](http://techno.org/electronic-music-guide/) - 
* [kevinhayeswilson.com](https://kevinhayeswilson.com/redraw/) - redraw state boundaries with 2016 us election data.

## About Explorable Explanations
*[&#8593; top](#contents)*
* [Explorable Explanations](http://explorableexplanations.com)
* [worrydream.com](http://worrydream.com/ScientificCommunicationAsSequentialArt/) - Scientific Communication As Sequential Art
* [worrydream.com](http://worrydream.com/ladderofabstraction/) - up and down the ladder of abstraction – a systemic approach to interactive visualization
* [worrydream.com](http://worrydream.com/explorableexplanations/) - bret victor's essay which coined the term "explorable explanations"
* [Reinventing Explanation](http://michaelnielsen.org/reinventing_explanation/) – prototyping an accessible explanation of simpson's paradox
* [blog.ncase.me](http://blog.ncase.me/explorable-explanations/) - design patterns for explorable explanations
* [simblob.blogspot.de](http://simblob.blogspot.de/2016/12/five-year-mission.html) - amit patel of red blob games looks back on 5 years of creating interactive explanations

## Tools for Explorable Explanations
*[&#8593; top](#contents)*
* [Tangle](http://worrydream.com/Tangle/) Js Library for reactive documents
* [Outside the box](http://simblob.blogspot.nl/2016/10/outside-box.html) On SVG and Arrows.
* [Implementing Draggable Handles](http://simblob.blogspot.nl/2014/09/implementing-draggable-handles.html)
* [RedBlobGames - Making Of](simblob.blogspot.nl/search/label/making-of)
* [GeoGebra](https://www.geogebra.org/materials/) - dynamic mathematics for learning and teaching 
* [aprt.us](http://aprt.us/) - apparatus, an open-source graphics editor and programming environment for creating interactive diagrams
* [awesome-livecoding](https://github.com/lvm/awesome-livecoding) - a curated list of live-coding resources.
* [Self-Lang](http://www.selflanguage.org) prototype-based dynamic object-oriented programming language, environment, and virtual machine
* [Lively Kernel](http://lively-kernel.org)

## Books
*[&#8593; top](#contents)*
* [mindstorms.media.mit.edu](http://mindstorms.media.mit.edu/) - "mindstorms: children, computers, and powerful ideas", an influential 1980 book by seymour papert
* [Elements of Euclid](https://archive.org/details/firstsixbooksofe00eucl) - oliver byrne's edition of euclid's "elements" uses colored diagrams and symbols instead of letters to proof theorems about math and geometry
